@@ -14,21 +14,17 @@ merkle_hash = "1"
 # Example: Get the hash of a directory using a single function
 The following code shows the simplest way to get the merkle hash of a directory:
 ```
-use std::path::Path;
 use merkle_hash::merkle_utils::get_merkle_hash;
 
-let path = Path::new("/root/to/get/paths/from");
-let merkle_hash = get_merkle_hash(path);
+let merkle_hash = get_merkle_hash("/root/to/get/paths/from");
 ```
 
 # Example: Get the hash of a directory using a combination of the utility functions
 The following code shows the more complicated way to get the merkle hash:
 ```
-use std::path::Path;
 use merkle_hash::{get_paths,get_hashes,find_merkle_hash};
 
-let root = Path::new("/root/to/get/paths/from");
-let paths = get_paths(root);
+let paths = get_paths("/root/to/get/paths/from");
 let hashes = get_hashes(&paths);
 let merkle_hash = find_merkle_hash(&hashes);
 ```
@@ -38,8 +34,7 @@ let merkle_hash = find_merkle_hash(&hashes);
 
 The following code demonstrates how to use the merkle hash function to get the single merkle hash from a few blake3 hashes:
 ```
-use std::str::FromStr;
-use blake3::{hash,Hash};
+use blake3::hash;
 use merkle_hash::merkle_utils::find_merkle_hash;
 
 let first_hash = hash(b"foo");
@@ -56,11 +51,9 @@ let merkle_hash = find_merkle_hash(&hashes);
 The following code uses a merkle item to find the merkle hash of a directory,
 you may want to use a merkle item if you want access to more of its functions such as getting all of its direct descendants and more:
 ```
-use std::path::PathBuf;
 use merkle_hash::merkle_item::MerkleItem;
 
-let path = PathBuf::from("/root/to/get/paths/from");
-let merkle_item = MerkleItem::new(path);
+let merkle_item = MerkleItem::new("/root/to/get/paths/from");
 let merkle_hash = merkle_item.get_hash();
 ```
  */
