@@ -13,13 +13,11 @@ use walkdir::WalkDir;
 /// # Examples
 ///
 /// ```
-/// use std::path::Path;
 /// use merkle_hash::merkle_utils::get_merkle_hash;
 ///
-/// let path = Path::new("/root/to/get/paths/from");
-/// let merkle_hash = get_merkle_hash(path);
+/// let merkle_hash = get_merkle_hash("/root/to/get/paths/from");
 /// ```
-pub fn get_merkle_hash(path: &Path) -> Option<Hash> {
+pub fn get_merkle_hash(path: impl AsRef<Path>) -> Option<Hash> {
     let tree = get_paths(path);
     let hashes = get_hashes(&tree);
     find_merkle_hash(&hashes)
@@ -89,11 +87,9 @@ pub fn find_merkle_hash(hashes: &[Hash]) -> Option<Hash> {
 /// # Examples
 ///
 /// ```
-/// use std::path::Path;
 /// use merkle_hash::merkle_utils::{get_paths, get_hashes};
 ///
-/// let root = Path::new("/root/to/get/paths/from");
-/// let paths = get_paths(root);
+/// let paths = get_paths("/root/to/get/paths/from");
 /// let hashes = get_hashes(&paths);
 /// ```
 pub fn get_hashes(paths: &BTreeMap<PathBuf, PathBuf>) -> Vec<Hash> {
@@ -126,19 +122,17 @@ pub fn get_hashes(paths: &BTreeMap<PathBuf, PathBuf>) -> Vec<Hash> {
 /// # Examples
 ///
 /// ```
-/// use std::path::Path;
 /// use merkle_hash::merkle_utils::get_paths;
 ///
-/// let root = Path::new("/root/to/get/paths/from");
-/// let paths = get_paths(root);
+/// let paths = get_paths("/root/to/get/paths/from");
 /// ```
-pub fn get_paths(root: &Path) -> BTreeMap<PathBuf, PathBuf> {
-    let paths: BTreeMap<PathBuf, PathBuf> = WalkDir::new(root)
+pub fn get_paths(root: impl AsRef<Path>) -> BTreeMap<PathBuf, PathBuf> {
+    let paths: BTreeMap<PathBuf, PathBuf> = WalkDir::new(&root)
         .into_iter()
         .flatten()
         .flat_map(|entry| {
-            let absolute_path = entry.path().to_path_buf();
-            let relative_path = absolute_path.strip_prefix(root).ok()?.to_path_buf();
+            let absolute_path = entry.into_path();
+            let relative_path = absolute_path.strip_prefix(&root).ok()?.to_path_buf();
             Some((relative_path, absolute_path))
         })
         .collect();
